package com.persagy.framework.ems.data.pojo.hbase;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.persagy.framework.ems.data.core.annotation.Column;
import com.persagy.framework.ems.data.core.annotation.Dimension;
import com.persagy.framework.ems.data.core.annotation.Entity;
import com.persagy.framework.ems.data.core.annotation.Index;
import com.persagy.framework.ems.data.core.annotation.Table;
import com.persagy.framework.ems.data.core.annotation.TimePatition;
import com.persagy.framework.ems.data.core.enumeration.EMSDimension;
import com.persagy.framework.ems.data.core.enumeration.Schema;
import com.persagy.framework.ems.data.core.enumeration.TimePatitionType;
import com.persagy.framework.ems.data.mvc.pojo.BusinessObject;

@Entity(name = "DataEnergyData")
@Table(name = "data_energydata", comment = "能源能耗", schema = Schema.ORIGINALDATA, 
		indexes = {
				@Index(columns = { "energyModelSign", "energyModelNodeSign", "data_time", "building"}, unique = true),
				@Index(columns = { "building","data_time","energyModelSign","energyModelNodeSign"})
})
@Dimension(dimension = EMSDimension.Time)
@TimePatition(column = "data_time", type = TimePatitionType.month)
public class DataEnergyData extends BusinessObject {

	private static final long serialVersionUID = 9123470427203487460L;

	@Column(order = 10, name = "building", length = 20, nullable = false, comment = "项目/建筑id")
	@JsonProperty("building")
	private String building;
	
	@Column(order = 20, name = "energyModelSign", length = 20, nullable = true, comment = "能耗模型id")
	@JsonProperty("energyModelSign")
	private String energyModelSign;
	
	@Column(order = 30, name = "energyModelNodeSign", length = 50, nullable = true, comment = "分项id")
	@JsonProperty("energyModelNodeSign")
	private String energyModelNodeSign;


	@Column(order = 40, name = "data_time", length = 0, nullable = false, comment = "数据时间")
	@JsonProperty("dataTime")
	private Date dataTime;

	@Column(order = 50, name = "data_value", length = 28, scale = 8, nullable = false, comment = "数据值")
	@JsonProperty("dataValue")
	private Double dataValue;

	public String getBuilding() {
		return building;
	}

	public void setBuilding(String building) {
		this.building = building;
	}

	public String getEnergyModelSign() {
		return energyModelSign;
	}

	public void setEnergyModelSign(String energyModelSign) {
		this.energyModelSign = energyModelSign;
	}

	public String getEnergyModelNodeSign() {
		return energyModelNodeSign;
	}

	public void setEnergyModelNodeSign(String energyModelNodeSign) {
		this.energyModelNodeSign = energyModelNodeSign;
	}

	public Date getDataTime() {
		return dataTime;
	}

	public void setDataTime(Date dataTime) {
		this.dataTime = dataTime;
	}

	public Double getDataValue() {
		return dataValue;
	}

	public void setDataValue(Double dataValue) {
		this.dataValue = dataValue;
	}

	
}
